@@ -4,7 +4,7 @@ methods that act upon a transfer function to gain functions such as the
 mass function.
 '''
 
-version = '1.0.5'
+version = '1.0.6'
 
 ###############################################################################
 # Some Imports
@@ -12,7 +12,7 @@ version = '1.0.5'
 from scipy.interpolate import InterpolatedUnivariateSpline as spline
 import scipy.integrate as intg
 import numpy as np
-from numpy import sin, cos, tan, abs, arctan, arccos, arcsin
+from numpy import sin, cos, tan, abs, arctan, arccos, arcsin, exp
 import collections
 # from scitools.std import sin,cos,tan,abs,arctan,arccos,arcsin #Must be in this form to work for some reason.
 
@@ -593,7 +593,7 @@ class Perturbations(object):
         Integrates the mass function above a certain mass to calculate the number of haloes above a certain mass
         
         INPUT:
-        mass_function: an array containing the mass function (log10)
+        mass_function: an array containing the mass function ( NOT log10)
         
         OUTPUT:
         ngtm: the number of haloes greater than M for all M in self.M
@@ -606,10 +606,12 @@ class Perturbations(object):
         mass_function = np.log10(mass_function[np.logical_not(np.isnan(mass_function))])
 
         # Interpolate the mass_function - this is in log-log space.
-        mf = spline(np.log10(M), mass_function, k=3)
+        mf = spline(np.log10(M), mass_function, k=1)
+        print "Interpolated MF at 10, 15: ", mf(10), mf(15)
 
         # Define max_M as either 17 or the maximum set by user
         max_M = np.max([17, np.log10(M[-1])])
+        print "MaxM: ", max_M
 
         for i, m in enumerate(self.M):
             if np.isnan(m):
@@ -620,9 +622,10 @@ class Perturbations(object):
                 mf_new = mf(M_new)
 
                 # Here we multiply by the mass because we are in log steps
-                integ = 10 ** (M_new + mf_new)
-                # Divide by ln(10) because we are in log10 steps
-                ngtm[i] = np.log10(intg.romb(integ, dx=dlnM) / np.log(10))
+                integ = 10 ** mf_new
+                #print integ
+                # Multiply by ln(10) because we are in log10 steps
+                ngtm[i] = intg.romb(integ, dx=dlnM) * np.log(10)
         return ngtm
 
     def MgtM(self, mass_function):
@@ -656,7 +659,7 @@ class Perturbations(object):
                 # Set up new grid with 4097 steps from m to M=17
                 M_new, dlnM = np.linspace(np.log10(m), max_M, 4097, retstep=True)
                 mf_new = mf(M_new)
-                integ = 10 ** (2 * M_new + mf_new)
+                integ = 10 ** (M_new + mf_new)
                 mgtm[i] = np.log10(intg.romb(integ, dx=dlnM) / np.log(10))
 
         return mgtm
@@ -692,7 +695,7 @@ class Perturbations(object):
                 # Set up new grid with 4097 steps from m to M=17
                 M_new, dlnM = np.linspace(min_M, np.log10(m), 4097, retstep=True)
                 mf_new = mf(M_new)
-                integ = 10 ** (M_new + mf_new)
+                integ = 10 ** (mf_new)
                 nltm[i] = np.log10(intg.romb(integ, dx=dlnM) / np.log(10))
 
         return nltm
@@ -729,7 +732,7 @@ class Perturbations(object):
                 # Set up new grid with 4097 steps from m to M=17
                 M_new, dlnM = np.linspace(min_M, np.log10(m), 4097, retstep=True)
                 mf_new = mf(M_new)
-                integ = 10 ** (2 * M_new + mf_new)
+                integ = 10 ** (M_new + mf_new)
                 mltm[i] = np.log10(intg.romb(integ, dx=dlnM) / np.log(10))
 
         return mltm
